==> phpBB-3.0.1_to_3.0.7_FR.zip: install/update/new/language/fr/search_ignore_words.php <==
<?php
/**
*
* search_ignore_words [Standard french]
* translated originally by PhpBB-fr.com <http://www.phpbb-fr.com/> and phpBB.biz <http://www.phpBB.biz>
*
* @package language
* @version $Id: search_ignore_words.php, v1.25 2010/02/25 16:47:00 dcz Exp $
* @copyright (c) 2005 phpBB Group
* @license http://opensource.org/licenses/gpl-license.php GNU Public License
*
*/

/**
* DO NOT CHANGE
*/
if (!defined('IN_PHPBB'))
{
	exit;
}

$words = array(
	'admin',
	'afin',
	'aide',
	'ainsi',
	'ajouter',
	'align',
	'aller',
	'allez',
	'alors',
	'amp',
	'and',
	'apres',
	'après',
	'assez',
	'attach',
	'aucun',
	'aucune',
	'aurait',
	'aussi',
	'autre',
	'autres',
	'aux',
	'avait',
	'avant',
	'avec',
	'avez',
	'avis',
	'avoir',
	'bah',
	'bas',
	'base',
	'bdd',
	'beaucoup',
	'ben',
	'bien',
	'bon',
	'bonjour',
	'bonne',
	'bravo',
	'bug',
	'car',
	'cas',
	'ceci',
	'cela',
	'celui',
	'certains',
	'ces',
	'cest',
	'cet',
	'cétait',
	'cette',
	'ceux',
	'change',
	'changer',
	'chaque',
	'chez',
	'chose',
	'code',
	'com',
	'comme',
	'comment',
	'confused',
	'connais',
	'contre',
	'cool',
	'coup',
	'crois',
	'cry',
	'daccord',
	'dans',
	'dautres',
	'davance',
	'davoir',
	'deja',
	'déjà',
	'depuis',
	'des',
	'dessus',
	'dêtre',
	'deux',
	'devrait',
	'dire',
	'dis',
	'dit',
	'dois',
	'doit',
	'donc',
	'donne',
	'donner',
	'dont',
	'dun',
	'dune',
	'dur',
	'edit',
	'effectivement',
	'effet',
	'elle',
	'encore',
	'end',
	'enfin',
	'ensuite',
	'entre',
	'erreur',
	'error',
	'est',
	'estce',
	'était',
	'etc',
	'été',
	'etre',
	'être',
	'euh',
	'exemple',
	'exemples',
	'façon',
	'faire',
	'fais',
	'fait',
	'faite',
	'faut',
	'fichier',
	'fichiers',
	'file',
	'files',
	'fin',
	'fini',
	'fois',
	'fonctionne',
	'fond',
	'font',
	'for',
	'forum',
	'forums',
	'free',
	'ftp',
	'genre',
	'gif',
	'grand',
	'gros',
	'haut',
	'hello',
	'heu',
	'heure',
	'href',
	'html',
	'ici',
	'idée',
	'ils',
	'img',
	'images',
	'infos',
	'installer',
	'jai',
	'jamais',
	'javais',
	'jen',
	'joint',
	'jour',
	'juste',
	'lai',
	'laisse',
	'lang2',
	'les',
	'leur',
	'leurs',
	'lien',
	'liens',
	'ligne',
	'line',
	'lire',
	'lisez',
	'lol',
	'lon',
	'lors',
	'lui',
	'mail',
	'maintenant',
	'mais',
	'mal',
	'manque',
	'marche',
	'med',
	'membre',
	'membres',
	'meme',
	'même',
	'menu',
	'merci',
	'mes',
	'message',
	'met',
	'mets',
	'mettre',
	'mieux',
	'mis',
	'mise',
	'mod',
	'modifier',
	'mods',
	'moi',
	'moins',
	'mois',
	'moment',
	'mon',
	'mrgreen',
	'nai',
	'nest',
	'net',
	'news',
	'nom',
	'non',
	'nos',
	'not',
	'notre',
	'nous',
	'nouveau',
	'oki',
	'on',
	'ont',
	'oops',
	'où',
	'ou',
	'ouais',
	'oué',
	'oui',
	'page',
	'par',
	'parce',
	'parle',
	'parler',
	'part',
	'partie',
	'partir',
	'pas',
	'passe',
	'passer',
	'pcp',
	'pense',
	'perso',
	'petit',
	'petite',
	'peu',
	'peut',
	'peut-être',
	'peutêtre',
	'peux',
	'php',
	'phpbb',
	'place',
	'plein',
	'plus',
	'plusieurs',
	'plutôt',
	'portail',
	'possible',
	'post',
	'poster',
	'pour',
	'pourquoi',
	'pouvez',
	'premier',
	'prend',
	'prendre',
	'prends',
	'pris',
	'problème',
	'probleme',
	'ptdr',
	'puis',
	'quand',
	'que',
	'quel',
	'quelle',
	'quelque',
	'quelques',
	'quelquun',
	'qui',
	'quil',
	'quils',
	'quoi',
	'quon',
	'quot',
	'quun',
	'rapide',
	'reçu',
	'regarde',
	'réglé',
	'regle',
	'reste',
	'rie',
	'rien',
	'rip',
	'roll',
	'sagit',
	'sais',
	'salut',
	'sans',
	'sauf',
	'savoir',
	'se',
	'semble',
	'sera',
	'serait',
	'ses',
	'sest',
	'seul',
	'seule',
	'shock',
	'sil',
	'simple',
	'sinon',
	'site',
	'soir',
	'soit',
	'son',
	'sont',
	'sous',
	'souvent',
	'sql',
	'src',
	'suis',
	'suite',
	'suivant',
	'sujet',
	'super',
	'sur',
	'sÃ»r',
	'surtout',
	'svp',
	'sympa',
	'table',
	'tant',
	'template',
	'templates',
	'temps',
	'tes',
	'test',
	'the',
	'theme',
	'tiens',
	'titre',
	'toi',
	'ton',
	'top',
	'topic',
	'toujours',
	'tous',
	'tout',
	'toute',
	'toutes',
	'tpl',
	'tres',
	'très',
	'trop',
	'trouve',
	'trouvé',
	'trouver',
	'truc',
	'tuto',
	'twisted',
	'type',
	'une',
	'url',
	'vais',
	'vas',
	'vers',
	'version',
	'veut',
	'veux',
	'via',
	'vide',
	'vie',
	'viens',
	'vient',
	'vite',
	'voici',
	'voila',
	'voilà',
	'voir',
	'vois',
	'voit',
	'vos',
	'votre',
	'voulais',
	'vous',
	'vrai',
	'vraiment',
	'web',
	'wink',
	'www',
	'zip',
);

?>

==> phpBB-3.0.3_to_3.0.13_FR.zip: install/update/new/language/fr/search_ignore_words.php <==
<?php
/**
*
* search_ignore_words [Standard french]
* @translated originally by phpBB.biz and phpBB-fr.com
* @translated currently by phpBB-fr.com (http://www.phpbb-fr.com)
*
* @package language
* @version $Id$
* @copyright (c) 2005 phpBB Group
* @license http://opensource.org/licenses/gpl-license.php GNU Public License
*
*/

if (!defined('IN_PHPBB'))
{
	exit;
}

$words = array(
	'admin',
	'afin',
	'aide',
	'ainsi',
	'ajouter',
	'align',
	'aller',
	'allez',
	'alors',
	'amp',
	'and',
	'apres',
	'après',
	'assez',
	'attach',
	'aucun',
	'aucune',
	'aurait',
	'aussi',
	'autre',
	'autres',
	'aux',
	'avait',
	'avant',
	'avec',
	'avez',
	'avis',
	'avoir',
	'bah',
	'bas',
	'base',
	'bdd',
	'beaucoup',
	'ben',
	'bien',
	'bon',
	'bonjour',
	'bonne',
	'bravo',
	'bug',
	'car',
	'cas',
	'ceci',
	'cela',
	'celui',
	'certains',
	'ces',
	'cest',
	'cet',
	'cétait',
	'cette',
	'ceux',
	'change',
	'changer',
	'chaque',
	'chez',
	'chose',
	'code',
	'com',
	'comme',
	'comment',
	'confused',
	'connais',
	'contre',
	'cool',
	'coup',
	'crois',
	'cry',
	'daccord',
	'dans',
	'dautres',
	'davance',
	'davoir',
	'deja',
	'déjà',
	'depuis',
	'des',
	'dessus',
	'dêtre',
	'deux',
	'devrait',
	'dire',
	'dis',
	'dit',
	'dois',
	'doit',
	'donc',
	'donne',
	'donner',
	'dont',
	'dun',
	'dune',
	'dur',
	'edit',
	'effectivement',
	'effet',
	'elle',
	'encore',
	'end',
	'enfin',
	'ensuite',
	'entre',
	'erreur',
	'error',
	'est',
	'estce',
	'était',
	'etc',
	'été',
	'etre',
	'être',
	'euh',
	'exemple',
	'exemples',
	'façon',
	'faire',
	'fais',
	'fait',
	'faite',
	'faut',
	'fichier',
	'fichiers',
	'file',
	'files',
	'fin',
	'fini',
	'fois',
	'fonctionne',
	'fond',
	'font',
	'for',
	'forum',
	'forums',
	'free',
	'ftp',
	'genre',
	'gif',
	'grand',
	'gros',
	'haut',
	'hello',
	'heu',
	'heure',
	'href',
	'html',
	'ici',
	'idée',
	'ils',
	'img',
	'images',
	'infos',
	'installer',
	'jai',
	'jamais',
	'javais',
	'jen',
	'joint',
	'jour',
	'juste',
	'lai',
	'laisse',
	'lang2',
	'les',
	'leur',
	'leurs',
	'lien',
	'liens',
	'ligne',
	'line',
	'lire',
	'lisez',
	'lol',
	'lon',
	'lors',
	'lui',
	'mail',
	'maintenant',
	'mais',
	'mal',
	'manque',
	'marche',
	'med',
	'membre',
	'membres',
	'meme',
	'même',
	'menu',
	'merci',
	'mes',
	'message',
	'met',
	'mets',
	'mettre',
	'mieux',
	'mis',
	'mise',
	'mod',
	'modifier',
	'mods',
	'moi',
	'moins',
	'mois',
	'moment',
	'mon',
	'mrgreen',
	'nai',
	'nest',
	'net',
	'news',
	'nom',
	'non',
	'nos',
	'not',
	'notre',
	'nous',
	'nouveau',
	'oki',
	'on',
	'ont',
	'oops',
	'où',
	'ou',
	'ouais',
	'oué',
	'oui',
	'page',
	'par',
	'parce',
	'parle',
	'parler',
	'part',
	'partie',
	'partir',
	'pas',
	'passe',
	'passer',
	'pcp',
	'pense',
	'perso',
	'petit',
	'petite',
	'peu',
	'peut',
	'peut-être',
	'peutêtre',
	'peux',
	'php',
	'phpbb',
	'place',
	'plein',
	'plus',
	'plusieurs',
	'plutôt',
	'portail',
	'possible',
	'post',
	'poster',
	'pour',
	'pourquoi',
	'pouvez',
	'premier',
	'prend',
	'prendre',
	'prends',
	'pris',
	'problème',
	'probleme',
	'ptdr',
	'puis',
	'quand',
	'que',
	'quel',
	'quelle',
	'quelque',
	'quelques',
	'quelquun',
	'qui',
	'quil',
	'quils',
	'quoi',
	'quon',
	'quot',
	'quun',
	'rapide',
	'reçu',
	'regarde',
	'réglé',
	'regle',
	'reste',
	'rie',
	'rien',
	'rip',
	'roll',
	'sagit',
	'sais',
	'salut',
	'sans',
	'sauf',
	'savoir',
	'se',
	'semble',
	'sera',
	'serait',
	'ses',
	'sest',
	'seul',
	'seule',
	'shock',
	'sil',
	'simple',
	'sinon',
	'site',
	'soir',
	'soit',
	'son',
	'sont',
	'sous',
	'souvent',
	'sql',
	'src',
	'suis',
	'suite',
	'suivant',
	'sujet',
	'super',
	'sur',
	'sûr',
	'surtout',
	'svp',
	'sympa',
	'table',
	'tant',
	'template',
	'templates',
	'temps',
	'tes',
	'test',
	'the',
	'theme',
	'tiens',
	'titre',
	'toi',
	'ton',
	'top',
	'topic',
	'toujours',
	'tous',
	'tout',
	'toute',
	'toutes',
	'tpl',
	'tres',
	'très',
	'trop',
	'trouve',
	'trouvé',
	'trouver',
	'truc',
	'tuto',
	'twisted',
	'type',
	'une',
	'url',
	'vais',
	'vas',
	'vers',
	'version',
	'veut',
	'veux',
	'via',
	'vide',
	'vie',
	'viens',
	'vient',
	'vite',
	'voici',
	'voila',
	'voilà',
	'voir',
	'vois',
	'voit',
	'vos',
	'votre',
	'voulais',
	'vous',
	'vrai',
	'vraiment',
	'web',
	'wink',
	'www',
	'zip',
);

?>
